﻿* Encoding: UTF-8.

*************************************************************************************************************************************************************************************************************
*                                                        SINTAXIS PARA EL CÁLCULO DE LOS ESTADÍSTICOS, TABULADOS E INDICADORES                        *
*                                                             MÓDULO MÉTODOS DE PRODUCCIÓN Y MEDIO AMBIENTE DE LA ENCUESTA                             *
*                                                                  DE SUPERFICIE Y PRODUCCIÓN AGROPECUARIA CONTINUA - ESPAC .                                  *
*                                                                                   REALIZADA POR: RAMIRO BENAVIDES - DEAGA.                                                    *
****************************************************************************************************************************************************************************************************************

*****IMPORTANTE****
*El módulo como parte de una encuesta emplea diversas bases de datos de la encuesta principal ESPAC, para la construcción de sus tabulados e indicadores.
*Las bases relacionadas a cultivos permanentes, transitorios, flores permanentes, flores transitorias y pastos cultivados se encuentran disponibles en el siguiente enlace.
*https://www.ecuadorencifras.gob.ec/estadisticas-agropecuarias-2/.
*La bases relacionadas de datos de información del capítulo 13 Ambiente y tecnificación se puede descarga del siguiente enlace:
 https://www.ecuadorencifras.gob.ec/informacion-agroambiental/.

**********************************************************************************************************************************************************************************************************

***MÓDULO MÉTODOS DE PRODUCCIÓN Y MEDIO AMBIENTE***
**Sección2. Utilización de recursos naturales***

* TÍTULO DE LA SINTAXIS DE INDICADOR:							   
* INDICADOR 7. SUPERFICIE NO FERTILIZADA POR TIPO DE USO DE SUELO*  				   
* OPERACIÓN ESTADÍSTICA:													   
* Encuesta de Superficie y Producción Agropecuaria Continua ESPAC_2023			   
* UNIDAD TÉCNICA RESPONSABLE: 												   
* Unidad de Estadísticas Ambientales					   
* ENTIDAD EJECUTORA:														   
* Instituto Nacional de Estadística y Censos (INEC)							   
*===========================================================================================================================*.
* Fecha de elaboración:          Abril - 2024						   
* Fecha última modificación:   Abril - 2024
		
*Indicaciones.

*1- Descargue la Bases de la página web: https://www.ecuadorencifras.gob.ec/informacion-agroambiental/.

*==============================================================
* 1. CONSTRUCCIÓN DEL INDICADOR: CASO DE CULTIVOS PERMANENTES
*==============================================================

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2023.sav) ***.

DATASET NAME Cultiv_Perm.
DATASET ACTIVATE Cultiv_Perm.

WEIGHT OFF.
FILTER OFF.

COMPUTE cultiv_perm = (rc_clacul >= 400 & rc_clacul <= 499). /* Los cultivos permanentes están en este rango de productos. 
FREQUENCIES cultiv_perm.

FILTER BY cultiv_perm.
WEIGHT BY fact_exp_fin.

* Reporte del indicador 1. Superficie no fertilizada para cultivos permanentes (ha).
CTABLES
  /VLABELS VARIABLES=cp_aferti cp_k409ha DISPLAY=LABEL
  /TABLE BY cp_aferti [C] > cp_k409ha [S][SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=cp_aferti ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 7. SUPERFICIES FERTILIZADAS Y NO FERTILIZADAS PARA CULTIVOS PERMANENTES (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*==============================================================
* 2. CONSTRUCCIÓN DEL INDICADOR: CASO DE CULTIVOS TRANSITORIOS
*==============================================================

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2023.sav) ***.

DATASET NAME Cultiv_Tran.
DATASET ACTIVATE Cultiv_Tran.

WEIGHT OFF.
FILTER OFF.

COMPUTE cultiv_tran = (rc_clacul >= 500 & rc_clacul <= 599). /* Los cultivos transitorios están en este rango de productos. 
FREQUENCIES cultiv_tran.

FILTER BY cultiv_tran.
WEIGHT BY fact_exp_fin.

* Reporte del indicador 2. Superficie no fertilizada para cultivos transitorios (ha).
CTABLES
  /VLABELS VARIABLES=ct_aferti ct_k510ha DISPLAY=LABEL
  /TABLE BY ct_aferti [C] > ct_k510ha [S][SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ct_aferti ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 7. SUPERFICIES FERTILIZADAS Y NO FERTILIZADAS PARA CULTIVOS TRANSITORIOS (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*==============================================================
* 3. CONSTRUCCIÓN DEL INDICADOR: CASO DE PASTOS CULTIVADOS
*==============================================================

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2023.sav) ***.

DATASET NAME Pastos_Cultiv.
DATASET ACTIVATE Pastos_Cultiv.

WEIGHT OFF.
FILTER OFF.

COMPUTE pastos_cultiv = (rc_clacul >= 751 & rc_clacul <= 771) | (rc_clacul = 780). /* Los pastos cultivados están en este rango de productos.
FREQUENCIES pastos_cultiv.

FILTER BY pastos_cultiv.
WEIGHT BY fact_exp_fin.

* Reporte del indicador 3. Superficie no fertilizada para pastos cultivados (ha).
CTABLES
  /VLABELS VARIABLES=cp_aferti cp_k409ha DISPLAY=LABEL
  /TABLE BY cp_aferti [C] > cp_k409ha [S][SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=cp_aferti ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 7. SUPERFICIES FERTILIZADAS Y NO FERTILIZADAS PARA PASTOS CULTIVADOS (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*==============================================================
* 4. CONSTRUCCIÓN DEL INDICADOR: CASO DE FLORES PERMANENTES
*==============================================================

*** ABRIR BASE DE FLORES PERMANENTES (fpnac2023.sav) ***.

DATASET NAME Flores_Perm.
DATASET ACTIVATE Flores_Perm.

WEIGHT BY fact_exp_fin.

* Reporte del indicador 4. Superficie no fertilizada para flores permanentes (ha).
CTABLES
  /VLABELS VARIABLES=fp_aferti fp_k706ha DISPLAY=LABEL
  /TABLE BY fp_aferti [C] > fp_k706ha [S][SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=fp_aferti ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 7. SUPERFICIES FERTILIZADAS Y NO FERTILIZADAS PARA FLORES PERMANENTES (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*=============================================================
* 5. CONSTRUCCIÓN DEL INDICADOR: CASO DE FLORES TRANSITORIAS
*=============================================================

*** ABRIR BASE DE FLORES TRANSITORIAS (ftnac2023.sav) ***.

DATASET NAME Flores_Tran.
DATASET ACTIVATE Flores_Tran.

WEIGHT BY fact_exp_fin.

* Reporte del indicador 5. Superficie no fertilizada para flores transitorios (ha).
CTABLES
  /VLABELS VARIABLES=ft_aferti ft_k720ha DISPLAY=LABEL
  /TABLE BY ft_aferti [C] > ft_k720ha [S][SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ft_aferti ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 7. SUPERFICIES FERTILIZADAS Y NO FERTILIZADAS PARA FLORES TRANSITORIAS (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


