﻿* Encoding: UTF-8.

*************************************************************************************************************************************************************************************************************
*                                                        SINTAXIS PARA EL CÁLCULO DE LOS ESTADÍSTICOS, TABULADOS E INDICADORES                        *
*                                                             MÓDULO MÉTODOS DE PRODUCCIÓN Y MEDIO AMBIENTE DE LA ENCUESTA                             *
*                                                                  DE SUPERFICIE Y PRODUCCIÓN AGROPECUARIA CONTINUA - ESPAC .                                  *
*                                                                                   REALIZADA POR: RAMIRO BENAVIDES - DEAGA.                                                    *
****************************************************************************************************************************************************************************************************************

*****IMPORTANTE****
*El módulo como parte de una encuesta emplea diversas bases de datos de la encuesta principal ESPAC, para la construcción de sus tabulados e indicadores.
*Las bases relacionadas a cultivos permanentes, transitorios, flores permanentes, flores transitorias y pastos cultivados se encuentran disponibles en el siguiente enlace.
*https://www.ecuadorencifras.gob.ec/estadisticas-agropecuarias-2/.
*La bases relacionadas de datos de información del capítulo 13 Ambiente y tecnificación se puede descarga del siguiente enlace:
 https://www.ecuadorencifras.gob.ec/informacion-agroambiental/.

**********************************************************************************************************************************************************************************************************

***MÓDULO MÉTODOS DE PRODUCCIÓN Y MEDIO AMBIENTE***
**Sección2. Utilización de recursos naturales***

* TÍTULO DE LA SINTAXIS DE INDICADOR:							   
* INDICADOR 9. SUPERFICIE CULTIVADA POR TIPOS DE USO DE LA TIERRA Y SEGÚN TIPO DE PLAGUICIDA APLICADO.*  				   
* OPERACIÓN ESTADÍSTICA:													   
* Encuesta de Superficie y Producción Agropecuaria Continua ESPAC_2023			   
* UNIDAD TÉCNICA RESPONSABLE: 												   
* Unidad de Estadísticas Ambientales					   
* ENTIDAD EJECUTORA:														   
* Instituto Nacional de Estadística y Censos (INEC)							   
*===========================================================================================================================*.
* Fecha de elaboración:          Abril - 2024						   
* Fecha última modificación:   Abril - 2024
		
*Indicaciones.

* Las bases de datos de cultivos permanentes y transitorios, flores permanentes y transitorias se encuentran en la página web:
 http://www.ecuadorencifras.gob.ec/informacion-agroambiental/

*=============================================================
* 1. CONSTRUCCIÓN DEL INDICADOR: CASO DE CULTIVOS.

WEIGHT OFF.
FILTER OFF.
COMPUTE cultiv_perm = (rc_clacul >= 400 & rc_clacul <= 499). /* Los cultivos permanentes están en este rango de productos. 
FREQUENCIES cultiv_perm.

COMPUTE Plag_Org = (cp_cantidad_po > 0).
COMPUTE Plag_Herb = (cp_cantidad_her_pq > 0).
COMPUTE Plag_Insec = (cp_cantidad_ins_pq > 0).
COMPUTE Plag_Fung = (cp_cantidad_fun_pq > 0).
COMPUTE Plag_Otro = (cp_cantidad_pq > 0).
EXECUTE.

FILTER BY cultiv_perm.
WEIGHT BY fact_exp_fin.

* Reporte del indicador.
CTABLES
  /VLABELS VARIABLES=Plag_Org cp_k409ha Plag_Herb Plag_Insec Plag_Fung Plag_Otro DISPLAY=LABEL
  /TABLE BY Plag_Org > cp_k409ha [SUM] + Plag_Herb > cp_k409ha [SUM] + Plag_Insec > cp_k409ha [SUM]
    + Plag_Fung > cp_k409ha [SUM] + Plag_Otro > cp_k409ha [SUM]
  /CATEGORIES VARIABLES=Plag_Org [1]
  /CATEGORIES VARIABLES=Plag_Herb [1]
  /CATEGORIES VARIABLES=Plag_Insec [1]
  /CATEGORIES VARIABLES=Plag_Fung [1]
  /CATEGORIES VARIABLES=Plag_Otro [1]
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 9a. SUPERFICIE PLANTADA DE CULTIVOS PERMANENTES, SEGÚN TIPO DE PLAGUICIDA APLICADO (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.
*=============================================================

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2023.sav)***.

DATASET NAME Cultiv_Perm.
DATASET ACTIVATE Cultiv_Perm.



*=============================================================
* 2. CONSTRUCCIÓN DEL INDICADOR: CASO DE CULTIVOS TRANSITORIOS
*=============================================================

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2023.sav)***.

DATASET NAME Cultiv_Tran.
DATASET ACTIVATE Cultiv_Tran.

WEIGHT OFF.
FILTER OFF.
COMPUTE cultiv_tran = (rc_clacul >= 500 & rc_clacul <= 599). /* Los cultivos permanentes están en este rango de productos. 
FREQUENCIES cultiv_tran.

COMPUTE Plag_Org = (ct_cantidad_po > 0).
COMPUTE Plag_Herb = (ct_cantidad_her_pq > 0).
COMPUTE Plag_Insec = (ct_cantidad_ins_pq > 0).
COMPUTE Plag_Fung = (ct_cantidad_fun_pq > 0).
COMPUTE Plag_Otro = (ct_cantidad_pq > 0).
EXECUTE.

FILTER BY cultiv_tran.
WEIGHT BY fact_exp_fin.

* Reporte del indicador.
CTABLES
  /VLABELS VARIABLES=Plag_Org ct_k510ha Plag_Herb Plag_Insec Plag_Fung Plag_Otro DISPLAY=LABEL
  /TABLE BY Plag_Org > ct_k510ha [SUM] + Plag_Herb > ct_k510ha [SUM] + Plag_Insec > ct_k510ha [SUM]
    + Plag_Fung > ct_k510ha [SUM] + Plag_Otro > ct_k510ha [SUM]
  /CATEGORIES VARIABLES=Plag_Org [1]
  /CATEGORIES VARIABLES=Plag_Herb [1]
  /CATEGORIES VARIABLES=Plag_Insec [1]
  /CATEGORIES VARIABLES=Plag_Fung [1]
  /CATEGORIES VARIABLES=Plag_Otro [1]
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 9b. SUPERFICIE SEMBRADA DE CULTIVOS TRANSITORIOS, SEGÚN TIPO DE PLAGUICIDA APLICADO (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*=======================================================
* 3. CONSTRUCCIÓN DEL INDICADOR: CASO DE PASTOS CULTIVADOS
*=======================================================

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2023.sav)***.

DATASET NAME Pastos_Cultiv.
DATASET ACTIVATE Pastos_Cultiv.

WEIGHT OFF.
FILTER OFF.
COMPUTE pastos_cultiv = (rc_clacul >= 751 & rc_clacul <= 771) | (rc_clacul = 780). /* Los pastos cultivados están en este rango de productos. 
FREQUENCIES pastos_cultiv.

COMPUTE Plag_Org = (cp_cantidad_po > 0).
COMPUTE Plag_Herb = (cp_cantidad_her_pq > 0).
COMPUTE Plag_Insec = (cp_cantidad_ins_pq > 0).
COMPUTE Plag_Fung = (cp_cantidad_fun_pq > 0).
COMPUTE Plag_Otro = (cp_cantidad_pq > 0).
EXECUTE.

FILTER BY pastos_cultiv.
WEIGHT BY fact_exp_fin.

* Reporte del indicador.
CTABLES
  /VLABELS VARIABLES=Plag_Org cp_k409ha Plag_Herb Plag_Insec Plag_Fung Plag_Otro DISPLAY=LABEL
  /TABLE BY Plag_Org > cp_k409ha [SUM] + Plag_Herb > cp_k409ha [SUM] + Plag_Insec > cp_k409ha [SUM]
    + Plag_Fung > cp_k409ha [SUM] + Plag_Otro > cp_k409ha [SUM]
  /CATEGORIES VARIABLES=Plag_Org [1]
  /CATEGORIES VARIABLES=Plag_Herb [1]
  /CATEGORIES VARIABLES=Plag_Insec [1]
  /CATEGORIES VARIABLES=Plag_Fung [1]
  /CATEGORIES VARIABLES=Plag_Otro [1]
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 9c. SUPERFICIE CULTIVADA DE PASTOS CULTIVADOS, SEGÚN TIPO DE PLAGUICIDA APLICADO (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*=============================================================
* 4. CONSTRUCCIÓN DEL INDICADOR: CASO DE FLORES PERMANENTES
*=============================================================

*** ABRIR BASE DE FLORES PERMANENTES (fpnac2023.sav)***.

DATASET NAME Flores_Perm.
DATASET ACTIVATE Flores_Perm.

WEIGHT OFF.
FILTER OFF.

COMPUTE Plag_Org = (fp_cantidad_po > 0).
COMPUTE Plag_Herb = (fp_cantidad_her_pq > 0).
COMPUTE Plag_Insec = (fp_cantidad_ins_pq > 0).
COMPUTE Plag_Fung = (fp_cantidad_fun_pq > 0).
COMPUTE Plag_Otro = (fp_cantidad_pq > 0).
EXECUTE.

WEIGHT BY fact_exp_fin.

* Reporte del indicador.
CTABLES
  /VLABELS VARIABLES=Plag_Org fp_k706ha Plag_Herb Plag_Insec Plag_Fung Plag_Otro DISPLAY=LABEL
  /TABLE BY Plag_Org > fp_k706ha [SUM] + Plag_Herb > fp_k706ha [SUM] + Plag_Insec > fp_k706ha [SUM]
    + Plag_Fung > fp_k706ha [SUM] + Plag_Otro > fp_k706ha [SUM]
  /CATEGORIES VARIABLES=Plag_Org [1]
  /CATEGORIES VARIABLES=Plag_Herb [1]
  /CATEGORIES VARIABLES=Plag_Insec [1]
  /CATEGORIES VARIABLES=Plag_Fung [1]
  /CATEGORIES VARIABLES=Plag_Otro [1]
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 9d. SUPERFICIE PLANTADA DE FLORES PERMANENTES, SEGÚN TIPO DE PLAGUICIDA APLICADO (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


*=============================================================
* 5. CONSTRUCCIÓN DEL INDICADOR: CASO DE FLORES TRANSITORIAS
*=============================================================

*** ABRIR BASE DE FLORES TRANSITORIAS (ftnac2023.sav)***.

DATASET NAME Flores_Tran.
DATASET ACTIVATE Flores_Tran.

WEIGHT OFF.
FILTER OFF.

COMPUTE Plag_Org = (ft_cantidad_po > 0).
COMPUTE Plag_Herb = (ft_cantidad_her_pq > 0).
COMPUTE Plag_Insec = (ft_cantidad_ins_pq > 0).
COMPUTE Plag_Fung = (ft_cantidad_fun_pq > 0).
COMPUTE Plag_Otro = (ft_cantidad_pq > 0).
EXECUTE.

WEIGHT BY fact_exp_fin.

* Reporte del indicador.
CTABLES
  /VLABELS VARIABLES=Plag_Org ft_k720ha Plag_Herb Plag_Insec Plag_Fung Plag_Otro DISPLAY=LABEL
  /TABLE BY Plag_Org > ft_k720ha [SUM] + Plag_Herb > ft_k720ha [SUM] + Plag_Insec > ft_k720ha [SUM]
    + Plag_Fung > ft_k720ha [SUM] + Plag_Otro > ft_k720ha [SUM]
  /CATEGORIES VARIABLES=Plag_Org [1]
  /CATEGORIES VARIABLES=Plag_Herb [1]
  /CATEGORIES VARIABLES=Plag_Insec [1]
  /CATEGORIES VARIABLES=Plag_Fung [1]
  /CATEGORIES VARIABLES=Plag_Otro [1]
  /CRITERIA CILEVEL=95
  /TITLES
    TITLE='INDICADOR 9e. SUPERFICIE SEMBRADA DE FLORES TRANSITORIAS, SEGÚN TIPO DE PLAGUICIDA APLICADO (ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2023'.


